 /*
 *  file      : popup.c
 *  project   : zoomc
 *  with      : Gtk-2
 *
 *  copyright : (C) 2010 - 2011 by Claude Bulin
 *
 *  ZOOMC - GTK+ implementation of the GNU shell command
 *  GNU General Public License
 *
 *  This file is part of ZOOMC.
 * 
 *  ZOOMC is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  at your option) any later version.
 * 
 *  ZOOMC is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with ZOOMC.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <glib/gprintf.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <math.h>	// M_PI
#include <cairo.h>
#include <cairo-pdf.h>
#include <cairo-ps.h>
#include <cairo-xlib.h>
#include <X11/Xlib.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../libzoomc/lib.h"
#endif

#include "global.h"
#include "poche.h"
#include "popup.h"


//
// POPUP FLIP
// 

// 
// 
void on_FlipHorizontal_activate( GtkMenuItem *menuitem, gpointer user_data )
{
	IMAGE *Image = (IMAGE *)user_data;
	
	Image->BoolFlipHorizontal = ( TRUE == Image->BoolFlipHorizontal ) ? FALSE : TRUE;
	gtk_widget_queue_draw( view.AdrDrawingarea );
}
// 
// 
void on_FlipVertical_activate( GtkMenuItem *menuitem, gpointer user_data )
{
	IMAGE *Image = (IMAGE *)user_data;
	
	Image->BoolFlipVertical = ( TRUE == Image->BoolFlipVertical ) ? FALSE : TRUE;
	gtk_widget_queue_draw( view.AdrDrawingarea );
}
// 
// 
void on_RemoveImage_activate( GtkMenuItem *menuitem, gpointer user_data )
{
	// IMAGE *Image = (IMAGE *)user_data;
	poche_remove_image();
}
// 
// 
void on_ImageFisrt_activate( GtkMenuItem *menuitem, gpointer user_data )
{
	IMAGE *Image = (IMAGE *)user_data;
	poche_set_selected_first_image( Image );
}
// 
// 
void on_ImageUp_activate( GtkMenuItem *menuitem, gpointer user_data )
{
	IMAGE *Image = (IMAGE *)user_data;
	poche_set_selected_up_image( Image );
}
// 
// 
void on_ImageDown_activate( GtkMenuItem *menuitem, gpointer user_data )
{
	IMAGE *Image = (IMAGE *)user_data;
	poche_set_selected_down_image( Image );
}
// 
// 
void on_ImageLast_activate( GtkMenuItem *menuitem, gpointer user_data )
{
	IMAGE *Image = (IMAGE *)user_data;
	poche_set_selected_last_image( Image );
}
// 
// 
void popup_flip( IMAGE *p_Image )
{
	GtkWidget *Menu;
	GtkWidget *FlipHorizontal;
	GtkWidget *FlipVertical;
	GtkWidget *Separate;
	GtkWidget *RemoveImage;
	GtkWidget *ImageFisrt;
	GtkWidget *ImageUp;
	GtkWidget *ImageDown;
	GtkWidget *ImageLast;

	Menu = gtk_menu_new ();
	gtk_widget_set_extension_events (Menu, GDK_EXTENSION_EVENTS_ALL);
	FlipHorizontal = gtk_menu_item_new_with_mnemonic (_("Retourner horizontalement"));
	gtk_widget_show (FlipHorizontal);
	gtk_container_add (GTK_CONTAINER (Menu), FlipHorizontal);
	
	FlipVertical = gtk_menu_item_new_with_mnemonic (_("Retourner verticalement"));
	gtk_widget_show (FlipVertical);
	gtk_container_add (GTK_CONTAINER (Menu), FlipVertical);
	
	Separate = gtk_separator_menu_item_new ();
	gtk_widget_show (Separate);
	gtk_container_add (GTK_CONTAINER (Menu), Separate);
		
	ImageFisrt = gtk_menu_item_new_with_mnemonic (_("Image au premier plan"));
	gtk_widget_show (ImageFisrt);
	gtk_container_add (GTK_CONTAINER (Menu), ImageFisrt);	
	
	ImageUp = gtk_menu_item_new_with_mnemonic (_("Image au dessus"));
	gtk_widget_show (ImageUp);
	gtk_container_add (GTK_CONTAINER (Menu), ImageUp);	

	ImageDown = gtk_menu_item_new_with_mnemonic (_("Image en dessous"));
	gtk_widget_show (ImageDown);
	gtk_container_add (GTK_CONTAINER (Menu), ImageDown);	
	
	ImageLast = gtk_menu_item_new_with_mnemonic (_("Image au dernier plan"));
	gtk_widget_show (ImageLast);
	gtk_container_add (GTK_CONTAINER (Menu), ImageLast);	
	
	Separate = gtk_separator_menu_item_new ();
	gtk_widget_show (Separate);
	gtk_container_add (GTK_CONTAINER (Menu), Separate);
		
	RemoveImage = gtk_menu_item_new_with_mnemonic (_("Effacer l'image"));
	gtk_widget_show (RemoveImage);
	gtk_container_add (GTK_CONTAINER (Menu), RemoveImage);	

	g_signal_connect ((gpointer) FlipHorizontal,   "activate", G_CALLBACK (on_FlipHorizontal_activate),   p_Image);
	g_signal_connect ((gpointer) FlipVertical,     "activate", G_CALLBACK (on_FlipVertical_activate),     p_Image);
	g_signal_connect ((gpointer) ImageFisrt,       "activate", G_CALLBACK (on_ImageFisrt_activate),       p_Image);
	g_signal_connect ((gpointer) ImageUp,          "activate", G_CALLBACK (on_ImageUp_activate),          p_Image);
	g_signal_connect ((gpointer) ImageDown,        "activate", G_CALLBACK (on_ImageDown_activate),        p_Image);
	g_signal_connect ((gpointer) ImageLast,        "activate", G_CALLBACK (on_ImageLast_activate),        p_Image);
	g_signal_connect ((gpointer) RemoveImage,      "activate", G_CALLBACK (on_RemoveImage_activate),      p_Image);
	
	GLADE_HOOKUP_OBJECT_NO_REF (Menu, Menu, "Menu");
	GLADE_HOOKUP_OBJECT (Menu, FlipHorizontal, "FlipHorizontal");
	GLADE_HOOKUP_OBJECT (Menu, FlipVertical,   "FlipVertical");
	GLADE_HOOKUP_OBJECT (Menu, RemoveImage,    "RemoveImage");
	gtk_menu_popup (GTK_MENU (Menu), NULL, NULL, NULL, NULL, 3, 0);
}

//
// POPUP REMOVE IMAGE IN VIEWPORT
// 

// 
// 
void on_viewport_remove_activate( GtkMenuItem *menuitem, gpointer user_data )
{
	GLIST_POCHETTE *gl = (GLIST_POCHETTE *)user_data;

	gl->BoolStructRemove = TRUE;
	pochedir_destroy_image( gl );
}
// 
// 
void popup_viewport( GLIST_POCHETTE *gl )
{
	GtkWidget *Menu;
	GtkWidget *RemoveImage;
	
	Menu = gtk_menu_new ();
	gtk_widget_set_extension_events (Menu, GDK_EXTENSION_EVENTS_ALL);
	RemoveImage = gtk_menu_item_new_with_mnemonic (_("Supprimer l'image de la liste"));
	gtk_widget_show (RemoveImage);
	gtk_container_add (GTK_CONTAINER (Menu), RemoveImage);
	
	g_signal_connect( (gpointer) RemoveImage, "activate", G_CALLBACK (on_viewport_remove_activate), gl );
	
	GLADE_HOOKUP_OBJECT_NO_REF (Menu, Menu, "Menu");
	GLADE_HOOKUP_OBJECT (Menu, RemoveImage, "RemoveImage");
	
	gtk_menu_popup (GTK_MENU (Menu), NULL, NULL, NULL, NULL, 3, 0);
}

